﻿using System;
using Windows.Data.Xml.Dom;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.Notifications;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "ToastNotification 클래스 : Dismissed 이벤트를 사용해 사용자 취소/타임아웃시 알림 센터에서 토스트 알림 제거하기";

            #endregion

            this.showToastNotificationButton.Click += showToastNotificationButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 토스트 알림 표시하기 버튼 클릭시 처리하기 - showToastNotificationButton_Click(sender, e)

        /// <summary>
        /// 토스트 알림 표시하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showToastNotificationButton_Click(object sender, RoutedEventArgs e)
        {
            ShowToastNotification("테스트", $"오늘은 {DateTime.Now:yyyy-MM-dd}일 입니다.", 4);
        }

        #endregion
        #region 토스트 알림 해산시 처리하기 - toastNotification_Dismissed(sender, e)

        /// <summary>
        /// 토스트 알림 해산시 처리하기
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void toastNotification_Dismissed(ToastNotification sender, ToastDismissedEventArgs e)
        {
            sender.Dismissed -= toastNotification_Dismissed;

            if(e.Reason == ToastDismissalReason.UserCanceled || e.Reason == ToastDismissalReason.TimedOut)
            {
                ToastNotificationManager.CreateToastNotifier().Hide(sender);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 토스트 알림 표시하기 - ShowToastNotification(title, content, duration)

        /// <summary>
        /// 토스트 알림 표시하기
        /// </summary>
        /// <param name="title">제목</param>
        /// <param name="content">내용</param>
        /// <param name="duration">지속 시간 (단위 : 초)</param>
        private void ShowToastNotification(string title, string content, int duration)
        {
            ToastNotifier toastNotifier = ToastNotificationManager.CreateToastNotifier();

            XmlDocument xmlDocument = ToastNotificationManager.GetTemplateContent(ToastTemplateType.ToastText02);
            XmlNodeList xmlNodeList = xmlDocument.GetElementsByTagName("text");

            xmlNodeList.Item(0).AppendChild(xmlDocument.CreateTextNode(title  ));
            xmlNodeList.Item(1).AppendChild(xmlDocument.CreateTextNode(content));

            xmlDocument.SelectSingleNode("/toast");

            XmlElement xmlElement = xmlDocument.CreateElement("audio");

            xmlElement.SetAttribute("src", "ms-winsoundevent:Notification.SMS");

            ToastNotification toastNotification = new ToastNotification(xmlDocument);

            toastNotification.ExpirationTime = DateTime.Now.AddSeconds(duration);

            toastNotification.Dismissed += toastNotification_Dismissed;

            toastNotifier.Show(toastNotification);
        }

        #endregion
    }
}